Struct form_data::Limits

source ·
pub struct Limits {
    pub field_name_size: Option<usize>,
    pub field_size: Option<usize>,
    pub fields: Option<usize>,
    pub file_size: Option<usize>,
    pub files: Option<usize>,
    pub parts: Option<usize>,
    pub stream_size: Option<u64>,
    pub buffer_size: usize,
}
Various limits on incoming data

Fields

field_name_size: Option<usize>

Max field name size

field_size: Option<usize>

Max field value size

fields: Option<usize>

Max number of non-file fields

file_size: Option<usize>

Max file size

files: Option<usize>

Max number of file fields

parts: Option<usize>

Max number of parts (fields + files)

stream_size: Option<u64>

Max number of whole stream

buffer_size: usize

Max number of buffer size

Implementations

Max number of field name size, defaults to 100.

Max number of field value size, defaults to 100KB.

Max number of file size, defaults to 10MB.

Max number of stream size, defaults to 200MB.

Max number of buffer size, defaults to 8KB

Max field name size

Max field value size

Max number of non-file fields

Max file size

Max number of file fields

Max number of parts (fields + files)

Max number of buffer size

Max number of whole stream size

Check parts

Check fields

Check files

Check stream size

Check file size

Check field size

Check field name size