Struct form_data::Field [−][src]
pub struct Field<T> {
pub length: usize,
pub index: usize,
pub name: String,
pub filename: Option<String>,
pub content_type: Option<Mime>,
pub headers: Option<HeaderMap>,
// some fields omitted
}Field
Fields
length: usizeThe payload size of Field.
index: usizeThe index of Field.
name: StringThe name of Field.
filename: Option<String>The filename of Field, optinal.
content_type: Option<Mime>The content_type of Field, optinal.
headers: Option<HeaderMap>The extras headers of Field, optinal.
Implementations
impl<T> Field<T>[src]
impl<T> Field<T>[src]pub fn headers_mut(&mut self) -> &mut Option<HeaderMap>[src]
pub fn headers_mut(&mut self) -> &mut Option<HeaderMap>[src]Gets mutable headers.
pub async fn bytes<E>(&mut self) -> Result<Bytes> where
T: Stream<Item = Result<Bytes, E>> + Unpin,
E: Into<Error>, [src]
pub async fn bytes<E>(&mut self) -> Result<Bytes> where
T: Stream<Item = Result<Bytes, E>> + Unpin,
E: Into<Error>, [src]Reads field data to bytes.
pub async fn copy_to<E, W>(&mut self, writer: &mut W) -> Result<u64> where
T: Stream<Item = Result<Bytes, E>> + Unpin,
E: Into<Error>,
W: AsyncWrite + Send + Unpin + 'static, [src]
pub async fn copy_to<E, W>(&mut self, writer: &mut W) -> Result<u64> where
T: Stream<Item = Result<Bytes, E>> + Unpin,
E: Into<Error>,
W: AsyncWrite + Send + Unpin + 'static, [src]Copys large buffer to AsyncRead, hyper can support large buffer,
8KB <= buffer <= 512KB, so if we want to handle large buffer.
Form::set_max_buf_size(512 * 1024);
3~4x performance improvement over the 8KB limitation of AsyncRead.
pub async fn copy_to_file<E>(&mut self, file: File) -> Result<u64> where
T: Stream<Item = Result<Bytes, E>> + Unpin,
E: Into<Error>, [src]
pub async fn copy_to_file<E>(&mut self, file: File) -> Result<u64> where
T: Stream<Item = Result<Bytes, E>> + Unpin,
E: Into<Error>, [src]Copys large buffer to File, hyper can support large buffer,
8KB <= buffer <= 512KB, so if we want to handle large buffer.
Form::set_max_buf_size(512 * 1024);
4x+ performance improvement over the 8KB limitation of AsyncRead.